==> mingw-w64-thorvg-0.13.8-1.src.tar.zst: thorvg-0.13.8/docs/html/classtvg_1_1Shape.js <==
var classtvg_1_1Shape =
[
    [ "appendArc", "classtvg_1_1Shape.html#a2f003a843ff42f6cee6a726f543836e3", null ],
    [ "appendCircle", "classtvg_1_1Shape.html#a52eccb2815eaa1231da9c389cd92ffa1", null ],
    [ "appendPath", "classtvg_1_1Shape.html#a3588ea30776a747a22b6ee82dadb9717", null ],
    [ "appendRect", "classtvg_1_1Shape.html#a8ef2587269a01153c9ea4ca4a8d31b49", null ],
    [ "close", "classtvg_1_1Shape.html#a2765987a2641ac1db76d5c64f00da697", null ],
    [ "cubicTo", "classtvg_1_1Shape.html#a7b71316176172fa052373bdb7c9efd29", null ],
    [ "fill", "classtvg_1_1Shape.html#a989edf4b4f68532ff25004fc0c7fe826", null ],
    [ "fill", "classtvg_1_1Shape.html#a02b95c15d0c2006134a95cdadf64e3f4", null ],
    [ "fill", "classtvg_1_1Shape.html#ad0cb7b2ec8d18d7c6d366cc84741682c", null ],
    [ "fill", "classtvg_1_1Shape.html#a0552551ad67547043167f7f382174e89", null ],
    [ "fillColor", "classtvg_1_1Shape.html#a8b4f00f01c2d24d6be2962ddf04a70ca", null ],
    [ "fillRule", "classtvg_1_1Shape.html#ac14cd997439012e1abf6c1b8d9f3d4aa", null ],
    [ "lineTo", "classtvg_1_1Shape.html#a9c28e9bbc6bd22dc62e891ffb3fa02cd", null ],
    [ "moveTo", "classtvg_1_1Shape.html#a59f97aaa973af7c58081690433286461", null ],
    [ "order", "classtvg_1_1Shape.html#aa7f1bade5864d60badcb5fae2b0fe034", null ],
    [ "pathCommands", "classtvg_1_1Shape.html#ac14d90c2c0130b66a9a33eb7d08101b7", null ],
    [ "pathCoords", "classtvg_1_1Shape.html#a818b1b358f0ed7ba448b6d804e087923", null ],
    [ "reset", "classtvg_1_1Shape.html#a8014640e362066901c2e2ebe6ddd1251", null ],
    [ "stroke", "classtvg_1_1Shape.html#ae79102d63897ad86a96afb4436c731e4", null ],
    [ "stroke", "classtvg_1_1Shape.html#a5ce764cd1970c7a7d76b209c4441bc73", null ],
    [ "stroke", "classtvg_1_1Shape.html#ab0b09b5064dff4931db9ea898b36dcc1", null ],
    [ "stroke", "classtvg_1_1Shape.html#a39068c9686211de862844dacabf92375", null ],
    [ "stroke", "classtvg_1_1Shape.html#ac416cad0d9e15079a112b1f609d19177", null ],
    [ "stroke", "classtvg_1_1Shape.html#aad81d8f86d9432eac25b00cc675c8d7f", null ],
    [ "strokeCap", "classtvg_1_1Shape.html#a0948989a7f0a9e253234cd9f53784674", null ],
    [ "strokeColor", "classtvg_1_1Shape.html#a6705be0d6481277e9bf17cc918597665", null ],
    [ "strokeDash", "classtvg_1_1Shape.html#afbc1e469219ee86df47d216f58af282a", null ],
    [ "strokeFill", "classtvg_1_1Shape.html#a08ce41b2d01d2d43980e5c26f4df111e", null ],
    [ "strokeJoin", "classtvg_1_1Shape.html#aac0235df4172e9c079689e5291c7ad5a", null ],
    [ "strokeMiterlimit", "classtvg_1_1Shape.html#a84ec91023314c914e900cade78a9095d", null ],
    [ "strokeMiterlimit", "classtvg_1_1Shape.html#ad8fb8f42c07ac68ef83383b05203ff6f", null ],
    [ "strokeWidth", "classtvg_1_1Shape.html#a1536ec32e91c29dd8300b0d4354773f9", null ]
];

==> mingw-w64-thorvg-0.15.13-1.src.tar.zst: thorvg-0.15.13/docs/html/classtvg_1_1Shape.js <==
var classtvg_1_1Shape =
[
    [ "appendArc", "classtvg_1_1Shape.html#a5c2815889f8a3d7d2c980cb225989e43", null ],
    [ "appendCircle", "classtvg_1_1Shape.html#a52eccb2815eaa1231da9c389cd92ffa1", null ],
    [ "appendPath", "classtvg_1_1Shape.html#a3588ea30776a747a22b6ee82dadb9717", null ],
    [ "appendRect", "classtvg_1_1Shape.html#a8ef2587269a01153c9ea4ca4a8d31b49", null ],
    [ "close", "classtvg_1_1Shape.html#a2765987a2641ac1db76d5c64f00da697", null ],
    [ "cubicTo", "classtvg_1_1Shape.html#a7b71316176172fa052373bdb7c9efd29", null ],
    [ "fill", "classtvg_1_1Shape.html#a989edf4b4f68532ff25004fc0c7fe826", null ],
    [ "fill", "classtvg_1_1Shape.html#a02b95c15d0c2006134a95cdadf64e3f4", null ],
    [ "fill", "classtvg_1_1Shape.html#ad0cb7b2ec8d18d7c6d366cc84741682c", null ],
    [ "fill", "classtvg_1_1Shape.html#a0552551ad67547043167f7f382174e89", null ],
    [ "fillColor", "classtvg_1_1Shape.html#a8b4f00f01c2d24d6be2962ddf04a70ca", null ],
    [ "fillRule", "classtvg_1_1Shape.html#ac14cd997439012e1abf6c1b8d9f3d4aa", null ],
    [ "lineTo", "classtvg_1_1Shape.html#a9c28e9bbc6bd22dc62e891ffb3fa02cd", null ],
    [ "moveTo", "classtvg_1_1Shape.html#a59f97aaa973af7c58081690433286461", null ],
    [ "order", "classtvg_1_1Shape.html#aa7f1bade5864d60badcb5fae2b0fe034", null ],
    [ "pathCommands", "classtvg_1_1Shape.html#ac14d90c2c0130b66a9a33eb7d08101b7", null ],
    [ "pathCoords", "classtvg_1_1Shape.html#a818b1b358f0ed7ba448b6d804e087923", null ],
    [ "reset", "classtvg_1_1Shape.html#a8014640e362066901c2e2ebe6ddd1251", null ],
    [ "stroke", "classtvg_1_1Shape.html#ae79102d63897ad86a96afb4436c731e4", null ],
    [ "stroke", "classtvg_1_1Shape.html#a5ce764cd1970c7a7d76b209c4441bc73", null ],
    [ "stroke", "classtvg_1_1Shape.html#ab0b09b5064dff4931db9ea898b36dcc1", null ],
    [ "stroke", "classtvg_1_1Shape.html#a39068c9686211de862844dacabf92375", null ],
    [ "stroke", "classtvg_1_1Shape.html#ac416cad0d9e15079a112b1f609d19177", null ],
    [ "stroke", "classtvg_1_1Shape.html#aad81d8f86d9432eac25b00cc675c8d7f", null ],
    [ "strokeCap", "classtvg_1_1Shape.html#a0948989a7f0a9e253234cd9f53784674", null ],
    [ "strokeColor", "classtvg_1_1Shape.html#a6705be0d6481277e9bf17cc918597665", null ],
    [ "strokeDash", "classtvg_1_1Shape.html#afbc1e469219ee86df47d216f58af282a", null ],
    [ "strokeFill", "classtvg_1_1Shape.html#a08ce41b2d01d2d43980e5c26f4df111e", null ],
    [ "strokeJoin", "classtvg_1_1Shape.html#aac0235df4172e9c079689e5291c7ad5a", null ],
    [ "strokeMiterlimit", "classtvg_1_1Shape.html#a84ec91023314c914e900cade78a9095d", null ],
    [ "strokeMiterlimit", "classtvg_1_1Shape.html#ad8fb8f42c07ac68ef83383b05203ff6f", null ],
    [ "strokeTrim", "classtvg_1_1Shape.html#ac69db0796d8e184334add6b0b94b1898", null ],
    [ "strokeWidth", "classtvg_1_1Shape.html#a1536ec32e91c29dd8300b0d4354773f9", null ],
    [ "type", "classtvg_1_1Shape.html#a0998d9f221df277cafde4934e3828aa2", null ]
];
